@@ -10,19 +10,19 @@ pytestmark = pytest.mark.skip(reason="only async testing makes sense")
 
 
 scwsource_module=os.environ.get('SCWDATA_SOURCE_MODULE','ddosa')
-ddosa_modules=os.environ.get('DDOSA_MODULE',"git://ddosa").split(",")
+ddosa_modules=os.environ.get('DDA_MODULE',"git://ddosa").split(",")
 
-def test_AutoRemoteDDOSA_construct():
-    remote=ddaclient.AutoRemoteDDOSA()
+def test_AutoRemoteDDA_construct():
+    remote=ddaclient.AutoRemoteDDA()
 
-#def test_AutoRemoteDDOSA_docker():
-#    remote=ddaclient.AutoRemoteDDOSA(config_version="docker_any")
+#def test_AutoRemoteDDA_docker():
+#    remote=ddaclient.AutoRemoteDDA(config_version="docker_any")
 
 test_scw=os.environ.get('TEST_SCW',"035200230010.001")
 
 
 def test_cat():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     product=remote.query(target="CatExtract",
                          modules=ddosa_modules,
@@ -33,7 +33,7 @@ def test_cat():
     print(("product:",product))
 
 def test_cat_injection():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     cat=['SourceCatalog',
          {
@@ -67,7 +67,7 @@ def test_cat_injection():
 
 
 def test_cat_injection_image():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     cat=['SourceCatalog',
          {
@@ -109,7 +109,7 @@ def test_cat_injection_image():
 
 
 def test_cat_injection_image_empty_cat():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     cat=['SourceCatalog',
          {
@@ -135,7 +135,7 @@ def test_cat_injection_image_empty_cat():
     #assert len([k[] for k in d])==0
 
 def test_cat_injection_spectra():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     cat=['SourceCatalog',
          {
@@ -178,7 +178,7 @@ def test_cat_injection_spectra():
     assert d[2].header['NAME'] == cat[1]['catalog'][0]['NAME']
 
 def test_lc():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     product = remote.query(target="lc_pick",
                            modules=ddosa_modules+["git://rangequery"],
@@ -195,7 +195,7 @@ def test_lc():
 
 
 def test_cat_injection_lc_pick():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     cat=['SourceCatalog',
          {
@@ -239,7 +239,7 @@ def test_cat_injection_lc_pick():
 
 
 def test_cat_injection_lc():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     cat=['SourceCatalog',
          {
@@ -282,7 +282,7 @@ def test_cat_injection_lc():
     assert d[2].header['NAME'] == cat[1]['catalog'][0]['NAME']
 
 def test_gti():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     product=remote.query(target="ibis_gti",
                          modules=ddosa_modules,
@@ -294,7 +294,7 @@ def test_gti():
 
 
 def test_image():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     product=remote.query(target="ii_skyimage",
                          modules=ddosa_modules,
@@ -304,7 +304,7 @@ def test_image():
 
 
 def test_spectrum():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     product=remote.query(target="ii_spectra_extract",
                          modules=ddosa_modules,
@@ -318,7 +318,7 @@ def test_spectrum():
 
 
 def test_spectrum_show_standard_catalog():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     product=remote.query(target="CatForSpectraFromImaging",
                          modules=["git://ddosa"]+ddosa_data_modules,
@@ -332,7 +332,7 @@ def test_spectrum_show_standard_catalog():
     assert os.path.exists(product.cat)
 
 def test_mosaic():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     product=remote.query(target="Mosaic",
                          modules=ddosa_modules+["git://osahk","git://mosaic",'git://rangequery'],
@@ -353,7 +353,7 @@ def test_mosaic():
     assert os.path.exists(product.skyima)
 
 def test_summary_injection():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     cat=['SourceCatalog',
              {
@@ -375,7 +375,7 @@ def test_summary_injection():
 
 
 def test_mosaic_injection():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
 
     cat=['SourceCatalog',
@@ -417,7 +417,7 @@ def test_mosaic_injection():
     assert os.path.exists(product.skyima)
 
 def test_sum_spectrum():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     try:
         product=remote.query(target="ISGRISpectraSum",
@@ -446,7 +446,7 @@ def test_sum_spectrum():
 
 
 def test_sum_spectrum_extract_all():
-    remote = ddaclient.AutoRemoteDDOSA()
+    remote = ddaclient.AutoRemoteDDA()
 
     try:
         product = remote.query(target="ISGRISpectraSum",
@@ -476,7 +476,7 @@ def test_sum_spectrum_extract_all():
 
 @pytest.mark.skip(reason="no way of currently testing this")
 def test_fit_one():
-    remote=ddaclient.AutoRemoteDDOSA()
+    remote=ddaclient.AutoRemoteDDA()
 
     product = remote.query(target="FitSourcePowerlaw",
                            modules=["ddosa","git://ddosadm","git://useresponse/cd7855bf7","git://process_isgri_spectra/2200bfd","git://rangequery",
@@ -492,7 +492,7 @@ def test_fit_one():
     print(("product:", product))
 
 def test_report_scwlist():
-    remote = ddaclient.AutoRemoteDDOSA()
+    remote = ddaclient.AutoRemoteDDA()
 
     try:
         product = remote.query(target="ReportScWList",
